@@ -1,4 +1,20 @@
-from __future__ import unicode_literals
+#!/usr/bin/env python
+# -*- coding: utf-8 -*-
+# $Id: lookups.py 10388 2017-10-21 15:16:00Z David $
+#
+# Copyright (c) 2017 Nuwa Information Co., Ltd, All Rights Reserved.
+#
+# Licensed under the Proprietary License,
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at our web site.
+#
+# See the License for the specific language governing permissions and
+# limitations under the License.
+#
+# $Author: David $
+# $Date: 2017-10-21 23:16:00 +0800 (Sat, 21 Oct 2017) $
+# $Revision: 10388 $
+
 
 from selectable.base import ModelLookup
 from selectable.registry import registry
