@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: views.py 10402 2017-10-24 08:16:47Z David $
+# $Id: views.py 10403 2017-10-24 08:52:47Z David $
 #
 # Copyright (c) 2012 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,21 +12,17 @@
 # limitations under the License.
 #
 # $Author: David $
-# $Date: 2017-10-24 16:16:47 +0800 (Tue, 24 Oct 2017) $
-# $Revision: 10402 $
+# $Date: 2017-10-24 16:52:47 +0800 (Tue, 24 Oct 2017) $
+# $Revision: 10403 $
 
-from django.shortcuts import render_to_response, get_object_or_404
-from django.utils.translation import ugettext_lazy as _
+from django.shortcuts import render_to_response
 from django.template import RequestContext
 
 from Iuppiter.extension.views import jsonpCallback, view
-from Iuppiter.dispatch import ThreadPool
+
 from Iuppiter.Logging import createLogger
 
 from Theophrastus.Utility import _slugify
-from Theophrastus.cloud.Mailer import CloudMailer
-
-from models import MailingList, Newsletter, ContactMailingStatus, Contact
 
 @jsonpCallback(noPadding=True)
 def getSlugName(request):
